<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('delivery');

// 记录访问日志
record_log('访问配送管理页面');
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>配送管理</h2>
        </div>

        <div class="content">


            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>配送员</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM delivery_staff");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">在职配送员：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM delivery_staff WHERE status = 1");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>待配送订单</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM delivery_tasks WHERE status = 1");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">待分配任务数</div>
                </div>

                <div class="dashboard-card">
                    <h3>今日配送</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM delivery_tasks WHERE DATE(create_time) = CURDATE()");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">配送中：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM delivery_tasks WHERE status = 2 AND DATE(create_time) = CURDATE()");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>配送评分</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT ROUND(AVG(rating), 1) as avg_rating FROM delivery_ratings");
                                        $result = $stmt->fetch();
                                        echo $result['avg_rating'] ? $result['avg_rating'] : '5.0';
                                        ?></div>
                    <div class="desc">平均满意度评分</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="staff.php" class="function-link">
                    <h3>配送员管理</h3>
                </a>
                <a href="task.php" class="function-link">
                    <h3>配送任务</h3>
                </a>
                <a href="track.php" class="function-link">
                    <h3>配送状态跟踪</h3>
                </a>
            </div>

            <h2>配送统计</h2>
            <div class="system-info">
                <table class="info-table">
                    <tr>
                        <td>今日已完成配送：</td>
                        <td><?php
                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM delivery_tasks WHERE status IN (3, 4) AND DATE(update_time) = CURDATE()");
                            $result = $stmt->fetch();
                            echo $result['count'];
                            ?> 单</td>
                    </tr>
                    <tr>
                        <td>配送失败率：</td>
                        <td><?php
                            $stmt = $pdo->query("
                                SELECT 
                                    ROUND(
                                        (SELECT COUNT(*) FROM delivery_tasks WHERE status = 5) / 
                                        (SELECT COUNT(*) FROM delivery_tasks WHERE status IN (3, 4, 5)) * 100, 
                                    2) as fail_rate
                            ");
                            $result = $stmt->fetch();
                            echo $result['fail_rate'] ? $result['fail_rate'] : '0';
                            ?> %</td>
                    </tr>
                    <tr>
                        <td>即时配送比例：</td>
                        <td><?php
                            $stmt = $pdo->query("
                                SELECT 
                                    ROUND(
                                        (SELECT COUNT(*) FROM delivery_tasks WHERE delivery_type = 1) / 
                                        (SELECT COUNT(*) FROM delivery_tasks) * 100, 
                                    2) as instant_rate
                            ");
                            $result = $stmt->fetch();
                            echo $result['instant_rate'] ? $result['instant_rate'] : '0';
                            ?> %</td>
                    </tr>
                    <tr>
                        <td>平均配送时间：</td>
                        <td>45 分钟</td>
                    </tr>
                    <tr>
                        <td>高峰配送时段：</td>
                        <td>14:00 - 17:00</td>
                    </tr>
                </table>
            </div>

            <h2>待处理配送任务</h2>
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>订单编号</th>
                            <th>配送类型</th>
                            <th>预计送达时间</th>
                            <th>配送地址</th>
                            <th>配送状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("
                            SELECT t.*, o.order_no
                            FROM delivery_tasks t
                            JOIN orders o ON t.order_id = o.id
                            WHERE t.status IN (1, 2)
                            ORDER BY t.expected_time ASC
                            LIMIT 5
                        ");
                        $pending_tasks = $stmt->fetchAll();

                        if (!empty($pending_tasks)):
                            foreach ($pending_tasks as $task):
                                $status_text = '';
                                $status_class = '';

                                switch ($task['status']) {
                                    case 1:
                                        $status_text = '待分配';
                                        $status_class = 'text-warning';
                                        break;
                                    case 2:
                                        $status_text = '配送中';
                                        $status_class = 'text-primary';
                                        break;
                                }

                                $delivery_type = $task['delivery_type'] == 1 ? '即时配送' : '预约配送';
                        ?>
                                <tr>
                                    <td><?php echo $task['order_no']; ?></td>
                                    <td><?php echo $delivery_type; ?></td>
                                    <td><?php echo date('Y-m-d H:i', strtotime($task['expected_time'])); ?></td>
                                    <td><?php echo $task['route_info']; ?></td>
                                    <td class="<?php echo $status_class; ?>"><?php echo $status_text; ?></td>
                                    <td>
                                        <a href="task.php?action=view&id=<?php echo $task['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                        <?php if ($task['status'] == 1): ?>
                                            <a href="task.php?action=assign&id=<?php echo $task['id']; ?>" class="btn btn-sm btn-primary">分配</a>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php
                            endforeach;
                        else:
                            ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无待处理配送任务</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>