<?php
// index.php 主框架页面
session_start();
require_once 'database_config.php';

// 检查用户是否已登录，未登录则重定向到登录页面
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit;
}

?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <style>
        /* 基础样式 */
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        body {
            font-family: 'Microsoft YaHei', Tahoma, Geneva, Verdana, sans-serif;
            background: #f0f2f5;
        }

        /* 侧边栏容器 */
        .sidebar {
            position: fixed;
            left: 0;
            top: 0;
            width: 200px;
            height: 100vh;
            background: #2c3e50;
            padding: 20px 0;
            box-shadow: 2px 0 5px rgba(0, 0, 0, 0.1);
            z-index: 100;
            overflow-y: auto;
        }

        /* 侧边栏导航 */
        .nav-menu {
            list-style: none;
        }

        .nav-item {
            margin: 5px 15px;
        }

        .nav-link {
            display: block;
            padding: 10px 15px;
            color: #ffffff !important;
            text-decoration: none;
            border-radius: 4px;
            transition: all 0.3s;
            font-size: 14px;
        }

        .nav-link:hover {
            background: #34495e;
            color: #ecf0f1;
        }

        /* 返回按钮样式 */
        .back-btn {
            background: #3498db;
            margin-bottom: 20px;
        }

        .back-btn:hover {
            background: #2980b9;
        }

        /* 折叠菜单 */
        .submenu {
            list-style: none;
            margin-left: 15px;
            display: none;
        }

        .nav-item.active .submenu {
            display: block;
        }

        .nav-item.active>a {
            background: #4CAF50;
            color: white !important;
        }

        .submenu .nav-link {
            padding: 8px 15px;
            font-size: 13px;
        }

        /* 选中状态样式 */
        .nav-link.selected {
            background: #4CAF50;
            color: white !important;
        }

        .submenu .nav-link.selected {
            background: #388E3C;
            color: white !important;
        }

        /* 右侧内容区 */
        .content-frame {
            margin-left: 200px;
            height: 100vh;
        }

        iframe {
            width: 100%;
            height: 100%;
            border: none;
            background: #fff;
        }

        /* 用户信息 */
        .user-info {
            color: #fff;
            padding: 10px 20px;
            margin-bottom: 20px;
            border-bottom: 1px solid #34495e;
            font-size: 14px;
        }

        /* 系统标题样式 */
        .main-title {
            text-align: center;
            background-color: #4CAF50;
            padding: 10px 0;
            margin-bottom: 0;
            border-bottom: 1px solid #e0e0e0;
        }

        .main-title h1 {
            margin: 0;
            color: #ffffff;
            font-size: 24px;
            font-weight: normal;
        }

        /* 页脚样式 */
        .main-footer {
            text-align: center;
            background-color: #f5f5f5;
            color: #333;
            padding: 10px 0;
            position: fixed;
            bottom: 0;
            width: calc(100% - 200px);
            margin-left: 0;
            font-size: 14px;
            border-top: 1px solid #e0e0e0;
        }
    </style>
</head>

<body>
    <!-- 侧边栏 -->
    <nav class="sidebar">
        <div class="user-info">
            用户: <?php echo htmlspecialchars($_SESSION['username']); ?>
        </div>
        <ul class="nav-menu">
            <li class="nav-item">
                <a href="logout.php" class="nav-link back-btn">
                    退出登录
                </a>
            </li>

            <!-- 1. 门店管理 -->
            <li class="nav-item" data-module="store">
                <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('store/index.php', 'store')">
                    门店管理
                </a>
                <ul class="submenu">
                    <li><a href="javascript:void(0)" class="nav-link" data-page="info" onclick="loadPage('store/info.php', 'store', 'info')">门店信息管理</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="employee" onclick="loadPage('store/employee.php', 'store', 'employee')">员工管理</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="stat" onclick="loadPage('store/stat.php', 'store', 'stat')">营业统计</a></li>
                </ul>
            </li>

            <!-- 2. 会员管理 -->
            <li class="nav-item" data-module="member">
                <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('member/index.php', 'member')">
                    会员管理
                </a>
                <ul class="submenu">
                    <li><a href="javascript:void(0)" class="nav-link" data-page="info" onclick="loadPage('member/info.php', 'member', 'info')">会员信息管理</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="points" onclick="loadPage('member/points.php', 'member', 'points')">会员积分管理</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="recharge" onclick="loadPage('member/recharge.php', 'member', 'recharge')">会员充值管理</a></li>
                </ul>
            </li>

            <!-- 3. 商品与库存管理 -->
            <li class="nav-item" data-module="product">
                <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('product/index.php', 'product')">
                    商品与库存管理
                </a>
                <ul class="submenu">
                    <li><a href="javascript:void(0)" class="nav-link" data-page="list" onclick="loadPage('product/list.php', 'product', 'list')">商品管理</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="inventory" onclick="loadPage('product/inventory.php', 'product', 'inventory')">库存管理</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="supplier" onclick="loadPage('product/supplier.php', 'product', 'supplier')">供应商管理</a></li>
                </ul>
            </li>

            <!-- 4. 订单管理 -->
            <li class="nav-item" data-module="order">
                <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('order/index.php', 'order')">
                    订单管理
                </a>
                <ul class="submenu">
                    <li><a href="javascript:void(0)" class="nav-link" data-page="list" onclick="loadPage('order/list.php', 'order', 'list')">订单列表</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="payment" onclick="loadPage('order/payment.php', 'order', 'payment')">订单支付</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="status" onclick="loadPage('order/status.php', 'order', 'status')">订单状态</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="refund" onclick="loadPage('order/refund.php', 'order', 'refund')">退款管理</a></li>
                </ul>
            </li>

            <!-- 5. 配送管理 -->
            <li class="nav-item" data-module="delivery">
                <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('delivery/index.php', 'delivery')">
                    配送管理
                </a>
                <ul class="submenu">
                    <li><a href="javascript:void(0)" class="nav-link" data-page="staff" onclick="loadPage('delivery/staff.php', 'delivery', 'staff')">配送员管理</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="task" onclick="loadPage('delivery/task.php', 'delivery', 'task')">配送任务</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="track" onclick="loadPage('delivery/track.php', 'delivery', 'track')">配送状态跟踪</a></li>
                </ul>
            </li>

            <!-- 6. 财务管理 -->
            <li class="nav-item" data-module="finance">
                <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('finance/index.php', 'finance')">
                    财务管理
                </a>
                <ul class="submenu">
                    <li><a href="javascript:void(0)" class="nav-link" data-page="income" onclick="loadPage('finance/income.php', 'finance', 'income')">收入管理</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="expense" onclick="loadPage('finance/expense.php', 'finance', 'expense')">支出管理</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="report" onclick="loadPage('finance/report.php', 'finance', 'report')">财务报表</a></li>
                </ul>
            </li>

            <!-- 7. 营销推广 -->
            <li class="nav-item" data-module="marketing">
                <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('marketing/index.php', 'marketing')">
                    营销推广
                </a>
                <ul class="submenu">
                    <li><a href="javascript:void(0)" class="nav-link" data-page="coupon" onclick="loadPage('marketing/coupon.php', 'marketing', 'coupon')">优惠券管理</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="promotion" onclick="loadPage('marketing/promotion.php', 'marketing', 'promotion')">促销活动</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="message" onclick="loadPage('marketing/message.php', 'marketing', 'message')">短信/邮件营销</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="referral" onclick="loadPage('marketing/referral.php', 'marketing', 'referral')">推荐返利</a></li>
                </ul>
            </li>

            <!-- 8. 数据统计与分析 -->
            <li class="nav-item" data-module="statistics">
                <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('statistics/index.php', 'statistics')">
                    数据统计与分析
                </a>
                <ul class="submenu">
                    <li><a href="javascript:void(0)" class="nav-link" data-page="sales" onclick="loadPage('statistics/sales.php', 'statistics', 'sales')">销售统计</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="member" onclick="loadPage('statistics/member.php', 'statistics', 'member')">会员数据</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="order" onclick="loadPage('statistics/order.php', 'statistics', 'order')">订单数据</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="inventory" onclick="loadPage('statistics/inventory.php', 'statistics', 'inventory')">库存数据</a></li>
                </ul>
            </li>

            <!-- 9. 系统设置 -->
            <li class="nav-item" data-module="system">
                <a href="javascript:void(0)" class="nav-link" onclick="toggleSubmenu(this.parentNode); loadPage('system/index.php', 'system')">
                    系统设置
                </a>
                <ul class="submenu">
                    <li><a href="javascript:void(0)" class="nav-link" data-page="user" onclick="loadPage('system/user.php', 'system', 'user')">用户管理</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="role" onclick="loadPage('system/role.php', 'system', 'role')">角色权限管理</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="log" onclick="loadPage('system/log.php', 'system', 'log')">操作日志</a></li>
                    <li><a href="javascript:void(0)" class="nav-link" data-page="backup" onclick="loadPage('system/backup.php', 'system', 'backup')">数据备份</a></li>
                </ul>
            </li>
        </ul>
    </nav>

    <!-- 右侧内容区 -->
    <div class="content-frame">
        <div class="main-title">
            <h1>鲜花门店发展管理系统（FloraEase）</h1>
        </div>
        <iframe name="contentFrame" id="mainFrame" src="store/index.php"></iframe>
        <div class="main-footer">
            版权所有 &copy; 2025 CA404 鲜花门店发展管理系统
        </div>
    </div>

    <script>
        // 当前选中的模块和页面
        let currentModule = 'store';
        let currentPage = '';

        // 页面加载函数
        function loadPage(pageUrl, module, page = '') {
            document.getElementById('mainFrame').src = pageUrl;

            // 更新当前选中的模块和页面
            currentModule = module;
            currentPage = page;

            // 更新菜单选中状态
            updateMenuSelection();
        }

        // 更新菜单选中状态
        function updateMenuSelection() {
            // 清除所有选中状态
            const allLinks = document.querySelectorAll('.nav-link');
            allLinks.forEach(link => {
                link.classList.remove('selected');
            });

            // 设置当前模块的选中状态
            const moduleItem = document.querySelector(`.nav-item[data-module="${currentModule}"]`);
            if (moduleItem) {
                const moduleLink = moduleItem.querySelector(':scope > a');
                moduleLink.classList.add('selected');

                // 如果有子页面，设置子页面的选中状态
                if (currentPage) {
                    const pageLink = moduleItem.querySelector(`.submenu .nav-link[data-page="${currentPage}"]`);
                    if (pageLink) {
                        pageLink.classList.add('selected');
                    }
                }
            }
        }

        // 切换子菜单显示/隐藏
        function toggleSubmenu(item) {
            // 先关闭所有已打开的子菜单
            const allItems = document.querySelectorAll('.nav-item');
            allItems.forEach(el => {
                if (el !== item && el.classList.contains('active')) {
                    el.classList.remove('active');
                }
            });

            // 切换当前项的active状态
            item.classList.toggle('active');

            // 更新菜单选中状态
            updateMenuSelection();
        }

        // 初始化加载默认页
        window.onload = function() {
            loadPage('store/index.php', 'store');

            // 默认展开第一个菜单
            const firstMenuItem = document.querySelector('.nav-item[data-module="store"]');
            if (firstMenuItem) {
                firstMenuItem.classList.add('active');
            }
        }
    </script>

</body>

</html>